@@ -20,10 +20,17 @@
 Gphoto_Messages* Gphoto_Messages::gpMessages=0;
 
 Gphoto_Messages* Gphoto_Messages::gpMessagesWrapper() {
-  
-  if (!gpMessages)
-    gpMessages = new Gphoto_Messages;
-  return gpMessages;
 
+    if (!gpMessages) {
+        gpMessages = new Gphoto_Messages;
+    }
+    return gpMessages;
 }
 
+void Gphoto_Messages::deleteMessagesWrapper()
+{
+    if (gpMessages) {
+        delete gpMessages;
+        gpMessages=0;
+    }
+}
