@@ -21,31 +21,32 @@
 #include <qobject.h>
 
 /**
-  *@author Renchi Raju
-  */
+ *@author Renchi Raju
+ */
 
 class Gphoto_Messages : public QObject {
 
-  Q_OBJECT
+    Q_OBJECT
 
-  friend class Gphoto_Interface;
-  friend class Gphoto_Status;
+    friend class Gphoto_Interface;
+    friend class Gphoto_Status;
 
- public:
+public:
 
-  static Gphoto_Messages* gpMessagesWrapper();
+    static Gphoto_Messages* gpMessagesWrapper();
+    static void deleteMessagesWrapper();
 
+signals:
 
- signals:
+    void errorMessage(const QString&);
+    void statusChanged(const QString&);
+    void progressChanged(int);
 
-  void statusChanged(const QString&);
-  void progressChanged(int);
+private:
 
- private:
+    Gphoto_Messages() : QObject() { };
 
-  Gphoto_Messages() : QObject() { };
-
-  static Gphoto_Messages* gpMessages;
+    static Gphoto_Messages* gpMessages;
 
 
 };
