@@ -1,10 +1,10 @@
 /***************************************************************************
                           main.cpp  -  description
                              -------------------
-    begin                : Wed Jan  9 18:01:17 CST 2002
+    begin                : Thu Jul 18 14:58:17 CDT 2002
     copyright            : (C) 2002 by Renchi Raju
     email                : renchi@green.tam.uiuc.edu
- ***************************************************************************/
+***************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -19,41 +19,36 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 
+#include "digikamsplash.h"
 #include "digikam.h"
 
 static const char *description =
-	I18N_NOOP("Digikam");
-// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
-	
-	
+I18N_NOOP("An Image Management Application For KDE");
+
+
 static KCmdLineOptions options[] =
 {
-  { 0, 0, 0 }
-  // INSERT YOUR COMMANDLINE OPTIONS HERE
+    { 0, 0, 0 }
 };
 
 int main(int argc, char *argv[])
 {
 
-  KAboutData aboutData( "digikam", I18N_NOOP("Digikam"),
-    VERSION, description, KAboutData::License_GPL,
-    "(c) 2002, Renchi Raju", 0, 0, "renchi@green.tam.uiuc.edu");
-  aboutData.addAuthor("Renchi Raju",0, "renchi@green.tam.uiuc.edu");
-  KCmdLineArgs::init( argc, argv, &aboutData );
-  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+    KAboutData aboutData( "digikam", I18N_NOOP("Digikam"),
+                          VERSION, description, KAboutData::License_GPL,
+                          "(c) 2002, Renchi Raju", 0, 0, "renchi@green.tam.uiuc.edu");
+    aboutData.addAuthor("Renchi Raju",0, "renchi@green.tam.uiuc.edu");
+    KCmdLineArgs::init( argc, argv, &aboutData );
+    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
-  KApplication app;
+    KApplication a;
+
+    DigikamSplash *splash = new DigikamSplash();
+    splash->show();
 
-  if (app.isRestored())
-  {
-    RESTORE(Digikam);
-  }
-  else 
-  {
     Digikam *digikam = new Digikam();
-    app.setMainWidget(digikam);
-    digikam->show();  
-  }
+    a.setMainWidget(digikam);
+    digikam->show();
 
-  return app.exec();
+    return a.exec();
 }
